@@ -2,12 +2,19 @@
 #include <stdlib.h>
 
 /*
- * strdup and strndup are useful, but technically not part of the 
+ * strdup and strndup are useful, but technically not part of the
  * C standard, and thus may be missing from some environments.
  * If libc provides these functions then it will use them,
  * otherwise it will fallback on these implementations.
  */
 
+#ifdef _MSC_VER
+#define EXPORT __declspec(dllexport)
+#else
+#define EXPORT
+#endif
+
+EXPORT
 char *
 ffi_platypus_memory__strdup(const char *olds)
 {
@@ -24,6 +31,7 @@ ffi_platypus_memory__strdup(const char *olds)
   return news;
 }
 
+EXPORT
 char *
 ffi_platypus_memory__strndup(const char *olds, size_t max)
 {
