@@ -2,10 +2,10 @@ package FFI::Platypus::Lang;
 
 use strict;
 use warnings;
-use 5.008001;
+use 5.008004;
 
 # ABSTRACT: Language specific customizations
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 
 
@@ -23,7 +23,7 @@ FFI::Platypus::Lang - Language specific customizations
 
 =head1 VERSION
 
-version 0.83
+version 1.34
 
 =head1 SYNOPSIS
 
@@ -73,9 +73,19 @@ Damyan Ivanov
 
 Ilya Pavlov (Ilya33)
 
+Petr Pisar (ppisar)
+
+Mohammad S Anwar (MANWAR)
+
+Håkon Hægland (hakonhagland, HAKONH)
+
+Meredith (merrilymeredith, MHOWARD)
+
+Diab Jerius (DJERIUS)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
