@@ -2,11 +2,12 @@ package FFI::Platypus::Type;
 
 use strict;
 use warnings;
+use 5.008004;
 use Carp qw( croak );
 require FFI::Platypus;
 
 # ABSTRACT: Defining types for FFI::Platypus
-our $VERSION = '1.10'; # VERSION
+our $VERSION = '1.34'; # VERSION
 
 # The TypeParser and Type classes are used internally ONLY and
 # are not to be exposed to the user.  External users should
@@ -57,7 +58,7 @@ FFI::Platypus::Type - Defining types for FFI::Platypus
 
 =head1 VERSION
 
-version 1.10
+version 1.34
 
 =head1 SYNOPSIS
 
@@ -230,11 +231,11 @@ Unsigned 32 bit integer (C<unsigned int>, C<uint32_t>)
 
 =item sint64
 
-Signed 64 bit integer (C<long> or C<long long>, C<int64_t>)
+Signed 64 bit integer (C<long long>, C<int64_t>)
 
 =item uint64
 
-Unsigned 64 bit integer (C<unsigned long> or C<unsigned long long>,
+Unsigned 64 bit integer (C<unsigned long long>,
 C<uint64_t>)
 
 =back
@@ -284,6 +285,12 @@ decide.  The C<malloc> function is defined in terms of C<size_t>:
 
 (Note that you can get C<malloc> from L<FFI::Platypus::Memory>).
 
+=item long, unsigned long
+
+On 64 bit systems, this is usually a 64 bit integer.  On 32 bit systems
+this is frequently a 32 bit integer (and C<long long> or
+C<unsigned long long> are for 64 bit).
+
 =back
 
 There are a number of other types that may or may not be available if
@@ -357,6 +364,9 @@ at install time.  See L<FFI::Platypus::Constant> for details.
 The main FAQ (L<FFI::Platypus/FAQ>) also has a discussion on dealing
 with constants and enumerated types.
 
+There is also a type plugin (L<FFI::Platypus::Type::Enum>) that can be helpful
+in writing interfaces that use enums.
+
 =head3 Boolean types
 
 At install time Platypus attempts to detect the correct type for C<bool>
@@ -663,7 +673,18 @@ Older versions of Platypus did not support pointers to strings or records.
 =head2 Records
 
 Records are structured data of a fixed length.  In C they are called
-C<struct>s To declare a record type, use C<record>:
+C<struct>s.
+
+The Platypus native way of working with structured data is via the C<record>
+type. There is also L<FFI::C> which has some overlapping functionality.
+Briefly, L<FFI::C> supports C<union> and arrays of structured types, but
+not passing structured data by-value, while the C<record> type doesn't
+support C<union> or arrays of structured data, but does support passing
+structured data by-value.  The remainder of this section will discuss
+the native Platypus C<record> type, but you should remember that for
+some applications L<FFI::C> might be more appropriate.
+
+To declare a record type, use C<record>:
 
  $ffi->type( 'record (42)' => 'my_record_of_size_42_bytes' );
 
@@ -1355,7 +1376,7 @@ Diab Jerius (DJERIUS)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019,2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
